==> tracker-0.7.11.tar.gz: tracker-0.7.11/src/tracker-extract/tracker-albumart-generic.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
/*
 * Copyright (C) 2008, Nokia
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 * Authors:
 * Philip Van Hoof <philip@codeminded.be>
 */

#ifndef __TRACKER_ALBUMART_GENERIC_H__
#define __TRACKER_ALBUMART_GENERIC_H__

#include <glib.h>

G_BEGIN_DECLS

gboolean  tracker_albumart_file_to_jpeg   (const gchar         *filename,
                                           const gchar         *target);
gboolean  tracker_albumart_buffer_to_jpeg (const unsigned char *buffer,
                                           size_t               len,
                                           const gchar         *buffer_mime,
                                           const gchar         *target);

G_END_DECLS

#endif /* __TRACKER_ALBUMART_GENERIC_H__ */

==> tracker-0.9.37.tar.gz: tracker-0.9.37/src/tracker-extract/tracker-albumart-generic.h <==
/*
 * Copyright (C) 2008, Nokia <ivan.frade@nokia.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA  02110-1301, USA.
 *
 * Authors:
 * Philip Van Hoof <philip@codeminded.be>
 */

#ifndef __TRACKER_ALBUMART_GENERIC_H__
#define __TRACKER_ALBUMART_GENERIC_H__

#include <glib.h>

G_BEGIN_DECLS

void      tracker_albumart_plugin_init     (void);
void      tracker_albumart_plugin_shutdown (void);

gboolean  tracker_albumart_file_to_jpeg    (const gchar         *filename,
                                            const gchar         *target);
gboolean  tracker_albumart_buffer_to_jpeg  (const unsigned char *buffer,
                                            size_t               len,
                                            const gchar         *buffer_mime,
                                            const gchar         *target);

G_END_DECLS

#endif /* __TRACKER_ALBUMART_GENERIC_H__ */
